@@ -2,9 +2,11 @@
 
 use std::fmt;
 
+use crate::{
+    serde::{Incoming, StringEnum},
+    OwnedRoomAliasId, OwnedRoomId,
+};
 use js_int::UInt;
-use ruma_identifiers::{MxcUri, RoomAliasId, RoomId, RoomName};
-use ruma_serde::Outgoing;
 use serde::{
     de::{Error, MapAccess, Visitor},
     ser::SerializeStruct,
@@ -12,6 +14,8 @@ use serde::{
 };
 use serde_json::Value as JsonValue;
 
+use crate::{OwnedMxcUri, PrivOwnedStr, RoomName};
+
 /// A chunk of a room list response, describing one room.
 ///
 /// To create an instance of this type, first create a `PublicRoomsChunkInit` and convert it via
@@ -23,9 +27,9 @@ pub struct PublicRoomsChunk {
     #[serde(skip_serializing_if = "Option::is_none")]
     #[cfg_attr(
         feature = "compat",
-        serde(default, deserialize_with = "ruma_serde::empty_string_as_none")
+        serde(default, deserialize_with = "crate::serde::empty_string_as_none")
     )]
-    pub canonical_alias: Option<Box<RoomAliasId>>,
+    pub canonical_alias: Option<OwnedRoomAliasId>,
 
     /// The name of the room, if any.
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -35,7 +39,7 @@ pub struct PublicRoomsChunk {
     pub num_joined_members: UInt,
 
     /// The ID of the room.
-    pub room_id: Box<RoomId>,
+    pub room_id: OwnedRoomId,
 
     /// The topic of the room, if any.
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -56,9 +60,13 @@ pub struct PublicRoomsChunk {
     #[serde(skip_serializing_if = "Option::is_none")]
     #[cfg_attr(
         feature = "compat",
-        serde(default, deserialize_with = "ruma_serde::empty_string_as_none")
+        serde(default, deserialize_with = "crate::serde::empty_string_as_none")
     )]
-    pub avatar_url: Option<Box<MxcUri>>,
+    pub avatar_url: Option<OwnedMxcUri>,
+
+    /// The join rule of the room.
+    #[serde(default, skip_serializing_if = "crate::serde::is_default")]
+    pub join_rule: PublicRoomJoinRule,
 }
 
 /// Initial set of mandatory fields of `PublicRoomsChunk`.
@@ -72,7 +80,7 @@ pub struct PublicRoomsChunkInit {
     pub num_joined_members: UInt,
 
     /// The ID of the room.
-    pub room_id: Box<RoomId>,
+    pub room_id: OwnedRoomId,
 
     /// Whether the room may be viewed by guest users without joining.
     pub world_readable: bool,
@@ -97,12 +105,13 @@ impl From<PublicRoomsChunkInit> for PublicRoomsChunk {
             world_readable,
             guest_can_join,
             avatar_url: None,
+            join_rule: PublicRoomJoinRule::default(),
         }
     }
 }
 
 /// A filter for public rooms lists
-#[derive(Clone, Debug, Default, Outgoing, Serialize)]
+#[derive(Clone, Debug, Default, Incoming, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[incoming_derive(Default)]
 pub struct Filter<'a> {
@@ -125,7 +134,7 @@ impl Filter<'_> {
 
 /// Information about which networks/protocols from application services on the
 /// homeserver from which to request rooms.
-#[derive(Clone, Debug, PartialEq, Eq, Outgoing)]
+#[derive(Clone, Debug, PartialEq, Eq, Incoming)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[incoming_derive(Clone, PartialEq, Eq, !Deserialize)]
 pub enum RoomNetwork<'a> {
@@ -223,6 +232,35 @@ impl<'de> Visitor<'de> for RoomNetworkVisitor {
     }
 }
 
+/// The rule used for users wishing to join a public room.
+#[doc = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/src/doc/string_enum.md"))]
+#[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
+#[ruma_enum(rename_all = "snake_case")]
+#[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
+pub enum PublicRoomJoinRule {
+    /// Users can request an invite to the room.
+    Knock,
+
+    /// Anyone can join the room without any prior action.
+    Public,
+
+    #[doc(hidden)]
+    _Custom(PrivOwnedStr),
+}
+
+impl PublicRoomJoinRule {
+    /// Returns the string name of this `PublicRoomJoinRule`.
+    pub fn as_str(&self) -> &str {
+        self.as_ref()
+    }
+}
+
+impl Default for PublicRoomJoinRule {
+    fn default() -> Self {
+        Self::Public
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
