@@ -17,12 +17,15 @@
 use std::hash::{Hash, Hasher};
 
 use indexmap::{Equivalent, IndexSet};
-use ruma_serde::{Raw, StringEnum};
 use serde::{Deserialize, Serialize};
 #[cfg(feature = "unstable-pre-spec")]
 use serde_json::Value as JsonValue;
+use tracing::instrument;
 
-use crate::PrivOwnedStr;
+use crate::{
+    serde::{Raw, StringEnum},
+    PrivOwnedStr,
+};
 
 mod action;
 mod condition;
@@ -99,6 +102,7 @@ impl Ruleset {
     ///
     /// * `event` - The raw JSON of a room message event.
     /// * `context` - The context of the message and room at the time of the event.
+    #[instrument(skip_all, fields(context.room_id = %context.room_id))]
     pub fn get_match<T>(
         &self,
         event: &Raw<T>,
@@ -116,6 +120,7 @@ impl Ruleset {
     ///
     /// * `event` - The raw JSON of a room message event.
     /// * `context` - The context of the message and room at the time of the event.
+    #[instrument(skip_all, fields(context.room_id = %context.room_id))]
     pub fn get_actions<T>(&self, event: &Raw<T>, context: &PushConditionRoomCtx) -> &[Action] {
         self.get_match(event, context).map(|rule| rule.actions()).unwrap_or(&[])
     }
@@ -406,7 +411,7 @@ pub struct PusherData {
     /// For more information, see [Sygnal docs][sygnal].
     ///
     /// [sygnal]: https://github.com/matrix-org/sygnal/blob/main/docs/applications.md#ios-applications-beware
-    // Not specified, issue: https://github.com/matrix-org/matrix-doc/issues/3474
+    // Not specified, issue: https://github.com/matrix-org/matrix-spec/issues/921
     #[cfg(feature = "unstable-pre-spec")]
     #[serde(default, skip_serializing_if = "JsonValue::is_null")]
     pub default_payload: JsonValue,
@@ -435,10 +440,8 @@ impl PusherData {
 /// A special format that the homeserver should use when sending notifications to a Push Gateway.
 /// Currently, only "event_id_only" is supported as of [Push Gateway API r0.1.1][spec].
 ///
-/// This type can hold an arbitrary string. To check for formats that are not available as a
-/// documented variant here, use its string representation, obtained through `.as_str()`.
-///
 /// [spec]: https://spec.matrix.org/v1.2/push-gateway-api/#homeserver-behaviour
+#[doc = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/src/doc/string_enum.md"))]
 #[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
 #[ruma_enum(rename_all = "snake_case")]
 #[non_exhaustive]
@@ -461,10 +464,8 @@ impl PushFormat {
 mod tests {
     use std::collections::BTreeMap;
 
-    use js_int::uint;
+    use js_int::{int, uint};
     use matches::assert_matches;
-    use ruma_identifiers::{room_id, user_id};
-    use ruma_serde::Raw;
     use serde_json::{
         from_value as from_json_value, json, to_value as to_json_value,
         value::RawValue as RawJsonValue, Value as JsonValue,
@@ -475,7 +476,7 @@ mod tests {
         condition::{PushCondition, PushConditionRoomCtx, RoomMemberCountIs},
         AnyPushRule, ConditionalPushRule, PatternedPushRule, Ruleset, SimplePushRule,
     };
-    use crate::power_levels::NotificationPowerLevels;
+    use crate::{power_levels::NotificationPowerLevels, room_id, serde::Raw, user_id};
 
     fn example_ruleset() -> Ruleset {
         let mut set = Ruleset::new();
@@ -963,20 +964,20 @@ mod tests {
 
         let context_one_to_one = &PushConditionRoomCtx {
             room_id: room_id!("!dm:server.name").to_owned(),
-            member_count: 2_u32.into(),
+            member_count: uint!(2),
             user_display_name: "Jolly Jumper".into(),
             users_power_levels: BTreeMap::new(),
-            default_power_level: 50.into(),
-            notification_power_levels: NotificationPowerLevels { room: 50.into() },
+            default_power_level: int!(50),
+            notification_power_levels: NotificationPowerLevels { room: int!(50) },
         };
 
         let context_public_room = &PushConditionRoomCtx {
             room_id: room_id!("!far_west:server.name").to_owned(),
-            member_count: 100_u32.into(),
+            member_count: uint!(100),
             user_display_name: "Jolly Jumper".into(),
             users_power_levels: BTreeMap::new(),
-            default_power_level: 50.into(),
-            notification_power_levels: NotificationPowerLevels { room: 50.into() },
+            default_power_level: int!(50),
+            notification_power_levels: NotificationPowerLevels { room: int!(50) },
         };
 
         let message = serde_json::from_str::<Raw<JsonValue>>(
@@ -1062,11 +1063,11 @@ mod tests {
     fn custom_ruleset_applies() {
         let context_one_to_one = &PushConditionRoomCtx {
             room_id: room_id!("!dm:server.name").to_owned(),
-            member_count: 2_u32.into(),
+            member_count: uint!(2),
             user_display_name: "Jolly Jumper".into(),
             users_power_levels: BTreeMap::new(),
-            default_power_level: 50.into(),
-            notification_power_levels: NotificationPowerLevels { room: 50.into() },
+            default_power_level: int!(50),
+            notification_power_levels: NotificationPowerLevels { room: int!(50) },
         };
 
         let message = serde_json::from_str::<Raw<JsonValue>>(
