@@ -1,14 +1,12 @@
 use std::{collections::BTreeMap, convert::TryFrom, ops::RangeBounds, str::FromStr};
 
 use js_int::{Int, UInt};
-use ruma_identifiers::{RoomId, UserId};
-use ruma_serde::Raw;
 use serde::{Deserialize, Serialize};
 use serde_json::{to_value as to_json_value, value::Value as JsonValue};
-use tracing::warn;
+use tracing::{instrument, warn};
 use wildmatch::WildMatch;
 
-use crate::power_levels::NotificationPowerLevels;
+use crate::{power_levels::NotificationPowerLevels, serde::Raw, OwnedRoomId, OwnedUserId, UserId};
 
 mod room_member_count_is;
 
@@ -116,7 +114,7 @@ impl PushCondition {
 #[allow(clippy::exhaustive_structs)]
 pub struct PushConditionRoomCtx {
     /// The ID of the room.
-    pub room_id: Box<RoomId>,
+    pub room_id: OwnedRoomId,
 
     /// The number of members in the room.
     pub member_count: UInt,
@@ -125,7 +123,7 @@ pub struct PushConditionRoomCtx {
     pub user_display_name: String,
 
     /// The power levels of the users of the room.
-    pub users_power_levels: BTreeMap<Box<UserId>, Int>,
+    pub users_power_levels: BTreeMap<OwnedUserId, Int>,
 
     /// The default power level of the users of the room.
     pub default_power_level: Int,
@@ -278,6 +276,7 @@ impl FlattenedJson {
     }
 
     /// Flatten and insert the `value` at `path`.
+    #[instrument(skip(self, value))]
     fn flatten_value(&mut self, value: JsonValue, path: String) {
         match value {
             JsonValue::Object(fields) => {
@@ -305,11 +304,10 @@ impl FlattenedJson {
 mod tests {
     use std::collections::BTreeMap;
 
-    use js_int::uint;
+    use crate::{room_id, serde::Raw, user_id};
+    use js_int::{int, uint};
     use maplit::btreemap;
     use matches::assert_matches;
-    use ruma_identifiers::{room_id, user_id};
-    use ruma_serde::Raw;
     use serde_json::{
         from_value as from_json_value, json, to_value as to_json_value, Value as JsonValue,
     };
@@ -458,7 +456,7 @@ mod tests {
         assert!("foobar".matches_pattern("foo*", false));
         assert!("foo bar".matches_pattern("foo*", false));
         assert!(!"foo".matches_pattern("foo?", false));
-        assert!("foo".matches_pattern("fo?", false));
+        assert!("fooo".matches_pattern("foo?", false));
         assert!("FOO".matches_pattern("foo", false));
         assert!("".matches_pattern("", false));
         assert!("".matches_pattern("*", false));
@@ -470,15 +468,15 @@ mod tests {
         let first_sender = user_id!("@worthy_whale:server.name").to_owned();
 
         let mut users_power_levels = BTreeMap::new();
-        users_power_levels.insert(first_sender, 25.into());
+        users_power_levels.insert(first_sender, int!(25));
 
         let context = PushConditionRoomCtx {
             room_id: room_id!("!room:server.name").to_owned(),
-            member_count: 3_u8.into(),
+            member_count: uint!(3),
             user_display_name: "Groovy Gorilla".into(),
             users_power_levels,
-            default_power_level: 50.into(),
-            notification_power_levels: NotificationPowerLevels { room: 50.into() },
+            default_power_level: int!(50),
+            notification_power_levels: NotificationPowerLevels { room: int!(50) },
         };
 
         let first_event_raw = serde_json::from_str::<Raw<JsonValue>>(
